@@ -5,7 +5,6 @@ use std::env;
 use structopt::StructOpt;
 
 mod bump;
-mod check;
 mod info;
 mod publish;
 mod util;
@@ -17,7 +16,7 @@ enum Command {
     Publish(PublishCommand),
 }
 
-#[tokio::main(flavor = "multi_thread", worker_threads = 4)]
+#[tokio::main]
 async fn main() -> Result<()> {
     let args = {
         let mut args = env::args().collect::<Vec<_>>();
