@@ -1,18 +1,19 @@
-use crate::info::fetch_ws_crates;
-use crate::util::can_publish;
-use crate::util::get_published_versions;
-use anyhow::bail;
-use anyhow::{Context, Result};
+use crate::{
+    info::fetch_ws_crates,
+    util::{can_publish, get_published_versions},
+};
+use anyhow::{bail, Context, Result};
 use cargo_metadata::{Package, PackageId};
-use petgraph::algo::toposort;
-use petgraph::graphmap::DiGraphMap;
+use petgraph::{algo::toposort, graphmap::DiGraphMap};
 use semver::Version;
-use std::collections::HashMap;
-use std::{process::Stdio, time::Duration};
+use std::{collections::HashMap, process::Stdio, time::Duration};
 use structopt::StructOpt;
-use tokio::io::{AsyncBufReadExt, BufReader};
-use tokio::process::{Child, Command};
-use tokio::{spawn, time::sleep};
+use tokio::{
+    io::{AsyncBufReadExt, BufReader},
+    process::{Child, Command},
+    spawn,
+    time::sleep,
+};
 
 /// Publishes crates and its dependencies.
 #[derive(Debug, StructOpt)]
@@ -24,6 +25,10 @@ pub struct PublishCommand {
     /// Allow publishing only dependencies
     #[structopt(long)]
     pub allow_only_deps: bool,
+
+    /// Skip verification.
+    #[structopt(long)]
+    pub no_verify: bool,
 }
 
 impl PublishCommand {
@@ -62,9 +67,15 @@ impl PublishCommand {
             let pkg = ws_packages.iter().find(|ws_pkg| ws_pkg.id == *p);
 
             if let Some(pkg) = pkg {
-                publish_if_possible(pkg, &published_versions)
-                    .await
-                    .context("failed to publish")?;
+                publish_if_possible(
+                    pkg,
+                    &published_versions,
+                    PublishOpts {
+                        no_verify: self.no_verify,
+                    },
+                )
+                .await
+                .context("failed to publish")?;
             }
         }
 
@@ -74,25 +85,38 @@ impl PublishCommand {
 async fn publish_if_possible(
     package: &Package,
     published_versions: &HashMap<String, Version>,
+    opts: PublishOpts,
 ) -> Result<()> {
     eprintln!("Checking if `{}` should be published", package.name);
 
     let published_version = &published_versions[&package.name];
 
     if *published_version < package.version {
-        publish(package).await.context("failed to publish")?;
+        publish(package, opts).await.context("failed to publish")?;
     }
 
     Ok(())
 }
 
-async fn publish(p: &Package) -> Result<()> {
+#[derive(Debug, Clone, Copy)]
+
+struct PublishOpts {
+    no_verify: bool,
+}
+
+async fn publish(p: &Package, opts: PublishOpts) -> Result<()> {
     sleep(Duration::new(5, 0)).await;
 
     eprintln!("Publishing `{}`", p.name);
 
-    let mut process: Child = Command::new("cargo")
-        .arg("publish")
+    let mut cmd = Command::new("cargo");
+
+    cmd.arg("publish");
+    if opts.no_verify {
+        cmd.arg("--no-verify");
+    }
+
+    let mut process: Child = cmd
         .arg("--color")
         .arg("always")
         .arg("--manifest-path")
